SystemOrganization addCategory: #'Seaside-Environment'!

WAObject subclass: #WAEnvironment
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Environment'!

WAEnvironment class
	instanceVariableNames: 'configuredApplicationDefaults configuredExceptionHandlingDefaults'!

WAEnvironment class
	instanceVariableNames: 'configuredApplicationDefaults configuredExceptionHandlingDefaults'!

!WAEnvironment class methodsFor: 'class initialization' stamp: 'jf 3/16/2009 08:31'!
configureApplicationDefaults
	(configuredApplicationDefaults ifNil: [ false ]) ifFalse: [
		WAAdmin applicationDefaults
			at: #responseGenerator put: WAHtmlResponseGenerator.
		configuredApplicationDefaults := true ].
	! !

!WAEnvironment class methodsFor: 'class initialization' stamp: 'jf 3/16/2009 08:32'!
configureApplicationExceptionHandlingDefaults
	(configuredExceptionHandlingDefaults ifNil: [ false ]) ifFalse: [
		WAAdmin applicationExceptionHandlingDefaults
			at: #exceptionHandler put: WAHtmlErrorHandler.
		configuredExceptionHandlingDefaults := true ].
	! !

!WAEnvironment class methodsFor: 'class initialization' stamp: 'jf 3/15/2009 18:51'!
initialize
	self configureApplicationDefaults.
	self configureApplicationExceptionHandlingDefaults.
	self registerDefaultRequestHandlers.
	self registerDefaultComponents! !

!WAEnvironment class methodsFor: 'registration' stamp: 'jf 3/15/2009 18:47'!
registerDefaultComponents
	WAPainter allSubclasses do: [ :each |
		(each class includesSelector: #initialize)
			ifTrue: [ each initialize ] ]! !

!WAEnvironment class methodsFor: 'registration' stamp: 'jf 3/15/2009 18:54'!
registerDefaultRequestHandlers
	WAFileHandler default: (WAFileHandler named: 'files').
	WAFileHandler default preferenceAt: #fileHandlerListingClass put: WAHtmlFileHandlerListing.
	WAAdmin defaultDispatcher register: WAFileHandler default! !

!WAEnvironment class methodsFor: 'registration' stamp: 'jf 3/15/2009 18:51'!
reloadApplications
	WAAdmin clearAll.
	self registerDefaultRequestHandlers.
	self registerDefaultComponents! !

!WAPackage class methodsFor: '*seaside-environment' stamp: 'jf 3/14/2009 11:49'!
seasideEnvironment
	^ self new
		name: 'Seaside-Environment';
		description: 'The standard Seaside distribution environment. This package can depend on all other code packages as needed.';
		addDependency: 'Seaside-Tools-Core';
		addDependency: 'Seaside-Core';
		addDependency: 'Seaside-Component';
		addDependency: 'Seaside-RenderLoop';
		addDependency: 'Seaside-Session';
		addDependency: 'Seaside-Canvas';
		yourself! !

WAErrorHandler subclass: #WAHtmlErrorHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Environment'!

!WAHtmlErrorHandler commentStamp: 'jf 11/10/2008 10:07' prior: 0!
This exception handler returns a simple HTML error message response for Warnings and Errors.

It provides two methods to allow the easy creation of custom error responses:

#titleForException:  - can be used to override the text displayed in the title
#renderContentForException:  - can be used to fully customize the HTML output!

!WAHtmlErrorHandler methodsFor: 'actions' stamp: 'lr 1/21/2009 18:19'!
handleDefault: anException
	self requestContext response
		internalError;
		contentType: WAMimeType textHtml;
		nextPutAll: (self rendererClass builder
			fullDocument: true;
			rootBlock: [ :root | root title: (self titleForException: anException) ];
			render: [ :html | self renderContentForException: anException on: html ]).
	self requestContext respond! !

!WAHtmlErrorHandler methodsFor: 'actions' stamp: 'jf 11/10/2008 10:04'!
renderContentForException: anException on: html
	html heading level1; with: anException description.
	html paragraph: 'Your request could not be completed. An exception occurred.'! !

!WAHtmlErrorHandler methodsFor: 'accessing' stamp: 'jf 12/29/2008 19:27'!
rendererClass
	^ WARenderCanvas! !

!WAHtmlErrorHandler methodsFor: 'content' stamp: 'jf 9/14/2008 20:28'!
titleForException: anException
	^ anException description! !

!WADispatcher class methodsFor: '*seaside-environment' stamp: 'jf 3/15/2009 18:52'!
resetAll
	self
		seasideDeprecatedApi: 'WADispatcher class>>#resetAll'
		details: 'Use WAEnvironment>>#reloadApplications.'.
	WAEnvironment reloadApplications! !

WAFileHandlerListing subclass: #WAHtmlFileHandlerListing
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Environment'!

!WAHtmlFileHandlerListing methodsFor: 'responding' stamp: 'jf 2/15/2009 21:26'!
responseForLibraries
	| title contents |
	title := 'Index of ', handler basePath.
	contents := WARenderCanvas builder
		fullDocument: true;
		rootBlock: [ :html | html title: title ];
		render: [ :html |
			html heading: title.
			html unorderedList: [
				handler libraries do: [ :each |
					html listItem: [
						html anchor
							url: (each urlOf: '');
							with: each name ] ] ] ].
	context response
		contentType: WAMimeType textHtml;
		nextPutAll: contents;
		respond! !

!WAHtmlFileHandlerListing methodsFor: 'responding' stamp: 'jf 2/15/2009 21:27'!
responseForLibrary: aLibrary
	| title contents |
	title := 'Index of ', aLibrary name.
	contents := WARenderCanvas builder
		fullDocument: true;
		rootBlock: [ :html | html title: title ];
		render: [ :html |
			html heading level: 1; with: title.
			html table: [
				html tableRow: [
					html tableHeading: 'Name'.
					html tableHeading: 'Size'.
					html tableHeading: 'Description' ].
				aLibrary fileSelectors do: [ :each |
					html tableRow: [
						html tableData: [
							html anchor
								url: (aLibrary urlOf: each);
								with: (aLibrary asFilename: each) ].
						html tableData: (aLibrary perform: each) size.
						html tableData: (aLibrary mimetypeForFile: (aLibrary asFilename: each)) ] ] ] ].
	context response
		contentType: WAMimeType textHtml;
		nextPutAll: contents;
		respond! !

WAResponseGenerator subclass: #WAHtmlResponseGenerator
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Environment'!

!WAHtmlResponseGenerator commentStamp: 'lr 2/20/2009 11:16' prior: 0!
This subclass overrides certain generation methods to create prettier HTML responses, instead of plain text.!

!WAHtmlResponseGenerator methodsFor: 'generation' stamp: 'lr 1/12/2009 15:10'!
forbidden
	self response
		forbidden;
		contentType: WAMimeType textHtml;
		nextPutAll: (WARenderCanvas builder
			fullDocument: true;
			rootBlock: [ :root | root title: 'Forbidden' ];
			render: [ :html |
				html heading: [
					html text: 'Error: you are forbidden to access "'.
					html text: self request url.
					html text: '"' ] ])! !

!WAHtmlResponseGenerator methodsFor: 'generation' stamp: 'lr 1/12/2009 15:11'!
notFound
	self response
		notFound;
		contentType: WAMimeType textHtml;
		nextPutAll: (WARenderCanvas builder
			fullDocument: true;
			rootBlock: [ :root | root title: 'Not Found' ];
			render: [ :html |
				html heading: [
					html text: 'Error: "'.
					html text: self request url.
					html text: '" not found' ] ])! !

!WAHtmlResponseGenerator methodsFor: 'generation' stamp: 'lr 1/12/2009 15:12'!
pageExpired
	self response
		doNotCache;
		contentType: WAMimeType textHtml;
		nextPutAll: (WARenderCanvas builder
			fullDocument: true;
			rootBlock: [ :root | root title: 'Page Expired' ];
			render: [ :html | 
				html heading: 'Page Expired'.
				html paragraph: 'This page has expired. Please use the back-button to navigate to the last valid page.' ])! !

!WAHtmlResponseGenerator methodsFor: 'generation' stamp: 'lr 1/12/2009 15:13'!
refreshAfter: aNumber location: aUrlOrString message: aString
	self response
		contentType: WAMimeType textHtml;
		refreshAfter: aNumber location: aUrlOrString;
		nextPutAll: (WARenderCanvas builder
			fullDocument: true;
			render: [ :html |
				html heading: aString.
				html paragraph: [
					html text: 'You are being redirected to '.
					html anchor
						url: aUrlOrString;
						with: aUrlOrString seasideString ] ])! !
WAEnvironment initialize!
